Enum coffer::code::Instruction[][src]

pub enum Instruction {
Show variants NoOp, PushNull, Push(OrDynamic<Constant>), Dup, DupX1, DupX2, Dup2, Dup2X1, Dup2X2, Pop1, Pop2, Jump(JumpConditionLabel), CompareLongs, CompareFloats(FloatTypeNaNBehavior), LocalVariable(LoadOrStoreLocalTypeu16), Array(LoadOrStoreArrayType), ArrayLength, IntOperation(IntTypeIntOperation), FloatOperation(FloatTypeFloatOperation), Throw, CheckCast(OrDynamic<ClassType>), InstanceOf(OrDynamic<ClassType>), NewArray(OrDynamic<Type>, u8), Monitor(MonitorOperation), New(OrDynamic<Cow<'static, str>>), Conversion(NumberTypeNumberType), ConvertInt(BitType), Return(Option<LocalType>), Field(GetOrPutMemberTypeOrDynamic<MemberRef>), InvokeExact(MemberTypeOrDynamic<MemberRef>), InvokeSpecial(OrDynamic<MemberRef>), InvokeDynamic(Dynamic), InvokeInterface(OrDynamic<MemberRef>, u8), Jsr(Label), Ret(u16), Swap, IntIncrement(u16i16), LineNumber(u16), TableSwitch { default: Label, low: i32, offsets: Vec<Label>, }, LookupSwitch { default: Label, table: IndexMap<i32, Label>, }, Label(Label),
}

Abstract tagged union to represent the instruction set. Note that while each valid instruction corresponds to one and only one enum variant, a value may correspond to multiple possibilities of actual operation used in bytecode. Normally, it should choose the option that takes the lowest space.

Some variants don’t actually appear in the code, but instead they represent attributes of the Code attribute. This gives benefits such that when modifying the class it doesn’t need to modify the indices of the attributes to remain valid.

However, StackMap frames will not be a variant because they become quite invalid after modifications made to code, thus, frames should be regenerated every time.

Variants

NoOp
PushNull

Push a null object reference.

Push a constant value to the current stack.

Dup
DupX1
DupX2
Dup2
Dup2X1
Dup2X2
Pop1
Pop2
CompareLongs
CompareFloats(FloatTypeNaNBehavior)
LocalVariable(LoadOrStoreLocalTypeu16)
ArrayLength
IntOperation(IntTypeIntOperation)
FloatOperation(FloatTypeFloatOperation)
Throw
CheckCast(OrDynamic<ClassType>)
InstanceOf(OrDynamic<ClassType>)
NewArray(OrDynamic<Type>, u8)
New(OrDynamic<Cow<'static, str>>)
Conversion(NumberTypeNumberType)

Conversion of the same types have no effect, it will not result in an instruction.

ConvertInt(BitType)
Return(Option<LocalType>)
InvokeSpecial(OrDynamic<MemberRef>)
InvokeDynamic(Dynamic)
InvokeInterface(OrDynamic<MemberRef>, u8)
Jsr(Label)
Ret(u16)
Swap
IntIncrement(u16i16)
LineNumber(u16)
TableSwitch
Show fields

Fields of TableSwitch

default: Labellow: i32offsets: Vec<Label>
LookupSwitch
Show fields

Fields of LookupSwitch

default: Labeltable: IndexMap<i32, Label>
Label(Label)

Not real in bytecode, used as a marker of location.