Struct coffer::dynamic::Dynamic [−][src]
A dynamic computed constant.
Note: dynamic computed constants are syntactically allowed to refer to themselves via the bootstrap method table but it will fail during resolution. Rust ownership rules prevent us from doing so.
Fields
name: Cow<'static, str>The name of the bootstrap method that will compute the constant value.
descriptor: TypeThe descriptor of the dynamically computed value. Must be a field descriptor.
Implementations
impl Dynamic[src]
impl Dynamic[src]pub fn new<N: Into<Cow<'static, str>>, D: Into<Type>>(
bsm: BootstrapMethod,
name: N,
descriptor: D
) -> Dynamic[src]
bsm: BootstrapMethod,
name: N,
descriptor: D
) -> Dynamic
Creates a new dynamic computed constant.
pub fn bsm(&self) -> &BootstrapMethod[src]
Returns an immutable reference to the bootstrap method of this dynamic computed constant.
pub fn bsm_mut(&mut self) -> &mut BootstrapMethod[src]
Returns a mutable reference to the bootstrap method of this dynamic computed constant.
pub fn into_inner(self) -> (Option<BootstrapMethod>, Cow<'static, str>, Type)[src]